==> knk-0.1.3.tgz: package/es/components/business/chance/chance_type_select.js <==
/**
 * 通过业务线获取对应的机会类型
 */
import React from 'react';
import AjaxSelect from '../../basic/form_item/ajax_select';
import DynamicAjaxSelect from '../../basic/form_item/dynamic_ajax_select';
import { Col, Row } from 'antd';
var ChanceTypeSelect = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var chanceTypeSelectRef = React.useRef();
  chanceTypeSelectRef = ref;

  var handleChanceChange = function handleChanceChange(data) {
    var onChange = props.onChange,
        value = props.value;
    onChange(Object.assign({}, value, {
      chanceGroupId: data,
      chanceTypeId: '',
      type: 'chanceGroup'
    }));
  };

  var handleChanceTypeChange = function handleChanceTypeChange(data) {
    var onChange = props.onChange,
        value = props.value;
    var result = {
      chanceType: data.chanceType,
      chanceGroupId: null,
      type: 'chanceType'
    };
    if (data.groupId) result.chanceGroupId = data.groupId;
    if (data) onChange(Object.assign({}, value, result));
  };

  var value = props.value,
      chanceTypeGroupApiPath = props.chanceTypeGroupApiPath,
      chanceTypeApiPath = props.chanceTypeApiPath,
      firstShowAll = props.firstShowAll,
      disabled = props.disabled;
  return /*#__PURE__*/React.createElement(Row, {
    gutter: 8,
    ref: chanceTypeSelectRef,
    className: "app-chance-type-select"
  }, /*#__PURE__*/React.createElement(Col, {
    span: 12
  }, /*#__PURE__*/React.createElement(AjaxSelect, {
    apiPath: chanceTypeGroupApiPath,
    apiMethod: "GET",
    listName: "\u4E1A\u52A1\u7EBF",
    listValueKey: "groupId",
    listNameKey: "groupName",
    onChange: handleChanceChange,
    value: value.chanceGroupId ? value.chanceGroupId : '',
    disabled: disabled
  })), /*#__PURE__*/React.createElement(Col, {
    span: 12
  }, /*#__PURE__*/React.createElement(DynamicAjaxSelect, {
    apiPath: chanceTypeApiPath,
    apiMethod: "GET",
    apiData: value.chanceGroupId ? {
      chanceGroupId: value.chanceGroupId
    } : {},
    listName: "\u673A\u4F1A\u7C7B\u578B",
    listValueKey: "chanceType",
    listNameKey: "chanceTypeName",
    onChange: handleChanceTypeChange,
    value: value.chanceType || '',
    firstShowAll: firstShowAll,
    disabled: disabled
  })));
});
export default ChanceTypeSelect;

==> knk-0.1.10.tgz: package/es/components/business/chance/chance_type_select.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
/**
 * 通过业务线获取对应的机会类型
 */
import React from 'react';
import AjaxSelect from '../../basic/form_item/ajax_select';
import DynamicAjaxSelect from '../../basic/form_item/dynamic_ajax_select';
import { Col, Row } from 'antd';
var ChanceTypeSelect = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var handleChanceChange = function handleChanceChange(data) {
    var onChange = props.onChange,
      value = props.value;
    onChange(_objectSpread(_objectSpread({}, value), {}, {
      chanceGroupId: data,
      chanceTypeId: '',
      type: 'chanceGroup'
    }));
  };
  var handleChanceTypeChange = function handleChanceTypeChange(data) {
    var onChange = props.onChange,
      value = props.value;
    var result = {
      chanceType: data.chanceType,
      chanceGroupId: null,
      type: 'chanceType'
    };
    if (data.groupId) result.chanceGroupId = data.groupId;
    if (data) onChange(_objectSpread(_objectSpread({}, value), result));
  };
  var value = props.value,
    chanceTypeGroupApiPath = props.chanceTypeGroupApiPath,
    chanceTypeApiPath = props.chanceTypeApiPath,
    firstShowAll = props.firstShowAll,
    disabled = props.disabled;
  return /*#__PURE__*/React.createElement(Row, {
    gutter: 8,
    ref: ref,
    className: "app-chance-type-select"
  }, /*#__PURE__*/React.createElement(Col, {
    span: 12
  }, /*#__PURE__*/React.createElement(AjaxSelect, {
    apiPath: chanceTypeGroupApiPath,
    apiMethod: "GET",
    listName: "\u4E1A\u52A1\u7EBF",
    listValueKey: "groupId",
    listNameKey: "groupName",
    onChange: handleChanceChange,
    value: value.chanceGroupId ? value.chanceGroupId : '',
    disabled: disabled
  })), /*#__PURE__*/React.createElement(Col, {
    span: 12
  }, /*#__PURE__*/React.createElement(DynamicAjaxSelect, {
    apiPath: chanceTypeApiPath,
    apiMethod: "GET",
    apiData: value.chanceGroupId ? {
      chanceGroupId: value.chanceGroupId
    } : {},
    listName: "\u673A\u4F1A\u7C7B\u578B",
    listValueKey: "chanceType",
    listNameKey: "chanceTypeName",
    onChange: handleChanceTypeChange,
    value: value.chanceType || '',
    firstShowAll: firstShowAll,
    disabled: disabled
  })));
});
export default ChanceTypeSelect;
